import { createContext, useContext, useState, useCallback } from "react";
import {
  getTrendingMedia,
  getMediaById,
  searchMedia,
} from "../services/mediaService";

const MediaContext = createContext();

export function useMedia() {
  const context = useContext(MediaContext);
  if (!context) {
    throw new Error("useMedia must be used within a MediaProvider");
  }
  return context;
}

export function MediaProvider({ children }) {
  const [trendingMovies, setTrendingMovies] = useState([]);
  const [trendingTvShows, setTrendingTvShows] = useState([]);
  const [trendingGames, setTrendingGames] = useState([]);
  const [currentMedia, setCurrentMedia] = useState(null);
  const [loading, setLoading] = useState(false);
  const [error, setError] = useState(null);
  const [searchResults, setSearchResults] = useState([]);

  const fetchTrendingMedia = useCallback(async () => {
    setLoading(true);
    setError(null);

    try {
      const [movies, tvShows, games] = await Promise.all([
        getTrendingMedia("movie"),
        getTrendingMedia("tv"),
        getTrendingMedia("game"),
      ]);

      setTrendingMovies(movies || []);
      setTrendingTvShows(tvShows || []);
      setTrendingGames(games || []);
    } catch (err) {
      setError(err.message || "Failed to fetch trending media");
      console.error("Fetch trending error:", err);
      // Сброс состояний на случай частичного успеха
      setTrendingMovies([]);
      setTrendingTvShows([]);
      setTrendingGames([]);
    } finally {
      setLoading(false);
    }
  }, []);

  const fetchMediaDetails = useCallback(async (id) => {
    if (!id) {
      setError("Invalid media ID");
      return;
    }

    setLoading(true);
    setError(null);
    setCurrentMedia(null);

    try {
      const data = await getMediaById(id);
      if (!data) {
        throw new Error("Media not found");
      }
      setCurrentMedia(data);
    } catch (err) {
      setError(err.message || "Failed to fetch media details");
      console.error("Fetch details error:", err);
    } finally {
      setLoading(false);
    }
  }, []);

  const handleSearch = useCallback(async (query) => {
    if (!query || !query.trim()) {
      setSearchResults([]);
      return;
    }

    setLoading(true);
    setError(null);

    try {
      const results = await searchMedia(query);
      setSearchResults(Array.isArray(results) ? results : []);
    } catch (err) {
      setError(err.message || "Search failed");
      console.error("Search error:", err);
      setSearchResults([]);
    } finally {
      setLoading(false);
    }
  }, []);

  const value = {
    trendingMovies,
    trendingTvShows,
    trendingGames,
    currentMedia,
    loading,
    error,
    searchResults,
    fetchTrendingMedia,
    fetchMediaDetails,
    handleSearch,
    clearError: () => setError(null),
    clearCurrentMedia: () => setCurrentMedia(null),
    clearSearchResults: () => setSearchResults([]),
  };

  return (
    <MediaContext.Provider value={value}>{children}</MediaContext.Provider>
  );
}
